# Metrics
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/metrics#overview)
  * [Creating a Chart](https://help.sap.com/docs/leanix/ea/metrics#creating-a-chart)
  * [Developer Resources](https://help.sap.com/docs/leanix/ea/metrics#developer-resources)
  * [Definitions](https://help.sap.com/docs/leanix/ea/metrics#definitions)
  * [Importing a Metric](https://help.sap.com/docs/leanix/ea/metrics#importing-a-metric)
  * [Using Python to Import Metrics](https://help.sap.com/docs/leanix/ea/metrics#using-python-to-import-metrics)
  * [API Documentation](https://help.sap.com/docs/leanix/ea/metrics#api-documentation)
  * [Using the Integration API](https://help.sap.com/docs/leanix/ea/metrics#using-the-integration-api)
  * [Steps to Create Integration](https://help.sap.com/docs/leanix/ea/metrics#steps-to-create-integration)


Metrics help you to display KPIs and their development over time in the context of the right Fact Sheet.
